; Converts date/time variables to string data.
;
; DT_TO_STR, dt_var, dates, times [,Date_Fmt= 1,2,3,4,5] [,Time_Fmt= -1,-2]
; 
;    dt_var : Date/time variable containing one and more date/time structures. 
;
;    Output
;      dates : A variable containing the date strings extracted from the date/time variable.
;      times : A variable containing the time strings extracted from date/time variable.
;
; Note:
;  The format of Date/time variable is the value returned by TODAY().
;  
; Copyright 2022 National Institute for Fusion Science, LABCOM
;
PRO dt_to_str, date_var, dates, times, Date_Fmt=dfmt, Time_Fmt=tfmt
compile_opt idl2, hidden
	IF NOT KEYWORD_SET(dfmt) THEN dfmt=1
	IF NOT KEYWORD_SET(tfmt) THEN tfmt=-1
	CASE dfmt OF
		1 : dates = string(date_var.MONTH,format='(i02)')+'/'+string(date_var.DAY,format='(i02)')+'/'+string(date_var.YEAR,format='(i0)')
		2 : dates = string(date_var.DAY,format='(i02)')+'-'+string(date_var.MONTH,format='(i02)')+'-'+string(date_var.YEAR,format='(i0)')
		3 : BEGIN
        		uy0 = [0,31,59,90,120,151,181,212,243,273,304,334,365]
        		uy1 = [0,31,60,91,121,152,182,213,244,274,305,335,366]
			IF ( date_var.YEAR mod 400) EQ 0 THEN days = uy1(date_var.MONTH-1)+date_var.DAY ELSE $
			IF ( date_var.YEAR mod 100) EQ 0 THEN days = uy0(date_var.MONTH-1)+date_var.DAY ELSE $
			IF ( date_var.YEAR mod 4  ) EQ 0 THEN days = uy1(date_var.MONTH-1)+date_var.DAY ELSE $
                                days = uy0(date_var.MONTH-1)+date_var.DAY
			dates = string(days,format='(i3)')+','+string(date_var.YEAR,format='(i0)')
		    END
		4 : BEGIN
			str_mon=['   ','Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec']
			dates = string(date_var.DAY,format='(i02)')+'/'+str_mon(date_var.MONTH)+'/'+string(date_var.YEAR,format='(i0)')
		    END
		5 : dates = string(date_var.YEAR,format='(i0)')+'-'+string(date_var.MONTH,format='(i02)')+'-'+string(date_var.DAY,format='(i02)')
	ENDCASE

	CASE tfmt OF
		-1 : times = string(date_var.HOUR,format='(i02)')+':'+string(date_var.MINUTE,format='(i02)')+':'+string(date_var.SECOND,format='(f06.3)')
		-2 : times = string(date_var.HOUR,format='(i02)')+string(date_var.MINUTE,format='(i02)')
	ENDCASE
END
