; Splits a string into an array of substrings called tokens.
;
; tokens = STRSPLIT_a(string, pattern)
;
;   string  : The scalar string that is scanned and split into tokens.
;   pattern : A scalar string specifying a regular expression. This regular expression is the delimiter used to determine where to split the string.
;
;   tokens  : A string array of substrings.
;
; Note:
;   Result = STRSPLIT( String [, Pattern] [, COUNT=variable] 
;                      [, ESCAPE=string | , /REGEX [, /FOLD_CASE]] 
;                      [, /EXTRACT | , LENGTH=variable] [, /PRESERVE_NULL] )
;
;    Returns an array containing either the positions of the substrings or 
;                                       the substrings themselves (if the EXTRACT)
;
; STRSPLIT(',8,12,',',')
;   PV-WAVE : ['', '8', '12']
;   GDL     : ['8', '12']
;   GDL     : ['', '8', '12', ''] with /PRESERVE_NULL
;
; STRSPLIT(',8,12,,L,',',')
;   PV-WAVE : ['', '8', '12', '', 'L']
;   GDL     : ['8', '12', 'L']
;   GDL     : ['', '8', '12', '', 'L', ''] with /PRESERVE_NULL
;
; Copyright 2022 National Institute for Fusion Science, LABCOM
; PV-WAVE is a registered trademark of Perforce Software, Inc.
;
FUNCTION strsplit_a, str, patt
compile_opt idl2, hidden
	return, strsplit( str, patt, /EXTRACT, /PRESERVE_NULL, /REGEX)
END
