; Sums an array of n dimensions over one of its dimensions.
; 
; result = SUM (array [,dim])
;
;   array: An array of n dimensions of any data type except string.
;   dim  : The dimension over which array is summed. 
;          The dim parameter must be a number in the range 0 <= dim <= (n-1), where n is the number of dimensions in array.
;          If this argument is not present , the scalar sum of all the array elements is returned.
;
; Note:
;   TOTAL( array [,dim] )
;        Returns the array sum for the specified dimension.
;
;        array: An array of n dimensions of any data type except string.
;        dim  : The dimension over which to sum, starting at one. 
;               If this argument is not present or zero, the scalar sum of all the array elements is returned.
;
; Copyright 2022 National Institute for Fusion Science, LABCOM
;
FUNCTION sum,array,dim
compile_opt idl2, hidden
        IF N_PARAMS() EQ 1 THEN dim=-1 $
        ELSE BEGIN
                IF dim LT 0 THEN Message,'Dimension value is out of bounds.'
        ENDELSE
	dim=dim+1
	aif=size(array)
	if( aif(0) lt dim ) then return,float(array)
	return,total(array,dim)
END
